#!/bin/sh

: ${GISBASE:?}

pgm=r.hplot.sh
cmd=gnuplot
term=
ylabel="cells"
xlabel="category"
interv=1
xrng=
yrng=
flags=-c
usage="
usage: $pgm [-z] [-T term] [-a lo:hi] [-i interval] [-o lo:hi]
		[-t title] [-x xlabel] [-y ylabel] mapname"

while [ $# -ge 1 ]
do
	case $1 in
	    -z)		flags=-cz ;;
	    -T)		term=$2; shift ;;
	    -T*)	term=`echo "$1" | sed s/-T//` ;;
	    -a)		xrng=$2; shift ;;
	    -a*)	xrng=`echo "$1" | sed s/-a//` ;;
	    -i)		interv=$2; shift ;;
	    -i*)	interv=`echo "$1" | sed s/-i//` ;;
	    -o)		yrng=$2; shift ;;
	    -o*)	yrng=`echo "$1" | sed s/-o//` ;;
	    -t)		title=$2; shift ;;
	    -t*)	title=`echo "$1" | sed s/-t//` ;;
	    -x)		xlabel=$2; shift ;;
	    -x*)	xlabel=`echo "$1" | sed s/-x//` ;;
	    -y)		ylabel=$2; shift ;;
	    -y*)	ylabel=`echo "$1" | sed s/-y//` ;;
	    *)		break ;;
	esac
	shift
done

if [ $# -ne 1 ]; then
	echo "$usage"
	exit 1
fi

eval `g.findfile element=cell file=$1`
if [ X"$file" = X ]
then
	echo "$pgm: Rastermap ($1) not found"
	exit 1
fi

map=$fullname

if [ X"$title" = X- ]
then
	title=
elif [ X"$title" = X ]
then
	title="$map in $LOCATION_NAME"
fi

if [ -t 1 ]
then
	tty=1
fi

tmp1=/tmp/grass.$$.1
tmp2=/tmp/grass.$$.2

trap "rm -f $tmp1 $tmp2; exit" 0 2 3 15

r.stats $flags input=$map | awk "
	BEGIN { sum = 0; ival = $interv; }
	{
		if (NR == 1) {
			if(\$1 < 0)
				hb = \$1 - \$1 % ival;
			else
				hb = \$1 - \$1 % ival + ival;
		}
		if (\$1 >= hb) {
			cb = hb - ival / 2;
			print cb, sum;
			while (hb <= \$1)
				hb += ival;
			sum = 0;
		}
		sum += \$2;
	}
	END { print cb + ival, sum; }" > $tmp1 || exit 1

{
if [ X"$term" != X ];	then echo "set term $term";	fi
echo "set title \"$title\""
echo "set ylabel \"$ylabel\""
echo "set xlabel \"$xlabel\""
echo "set boxwidth $interv"
echo "plot [$xrng] [$yrng] \"$tmp1\" with boxes"
if [ X"$tty" = X"1" ]; then echo "pause -1 \"Hit <return> to continue\""; fi
echo "quit"
} > $tmp2

$cmd $tmp2

exit 0
