#!/bin/sh

: ${GISBASE:?}

pgm=r.splot.sh
cmd=gnuplot
term=
ylabel=
xlabel=
size=
xrng=
yrng=
flags=-c
usage="
usage: $pgm [-z] [-T term] [-a lo:hi] [-o lo:hi] [-s wscale,hscale]
		[-t title] [-x xlabel] [-y ylabel] xmapname ymapname"

while [ $# -ge 2 ]
do
	case $1 in
	    -z)		flags=-cz ;;
	    -T)		term=$2; shift ;;
	    -T*)	term=`echo "$1" | sed s/-T//` ;;
	    -a)		xrng=$2; shift ;;
	    -a*)	xrng=`echo "$1" | sed s/-a//` ;;
	    -o)		yrng=$2; shift ;;
	    -o*)	yrng=`echo "$1" | sed s/-o//` ;;
	    -s)		size=$2; shift ;;
	    -s*)	size=`echo "$1" | sed s/-s//` ;;
	    -t)		title=$2; shift ;;
	    -t*)	title=`echo "$1" | sed s/-t//` ;;
	    -x)		xlabel=$2; shift ;;
	    -x*)	xlabel=`echo "$1" | sed s/-x//` ;;
	    -y)		ylabel=$2; shift ;;
	    -y*)	ylabel=`echo "$1" | sed s/-y//` ;;
	    *)		break ;;
	esac
	shift
done

if [ $# -ne 2 ]; then
	echo "$usage"
	exit 1
fi

eval `g.findfile element=cell file=$1`
if [ X"$file" = X ]
then
	echo "$pgm: Rastermap ($1) not found"
	exit 1
fi

map1=$fullname
: ${xlabel:="$1"}

eval `g.findfile element=cell file=$2`
if [ X"$file" = X ]
then
	echo "$pgm: Rastermap ($2) not found"
	exit 1
fi

map2=$fullname
: ${ylabel:="$2"}

if [ X"$title" = X- ]
then
	title=
elif [ X"$title" = X ]
then
	title="$map2 vs $map1 in $LOCATION_NAME"
fi

if [ -t 1 ]
then
	tty=1
fi

tmp1=/tmp/grass.$$.1
tmp2=/tmp/grass.$$.2

trap "rm -f $tmp1 $tmp2; exit" 0 2 3 15

r.stats $flags input=$map1,$map2 > $tmp1 || exit 1

{
if [ X"$term" != X ];	then echo "set term $term";	fi
echo "set title \"$title\""
echo "set ylabel \"$ylabel\""
echo "set xlabel \"$xlabel\""
if [ X"$size" != X ];	then echo "set size $size";	fi
echo "plot [$xrng] [$yrng] \"$tmp1\" with points"
if [ X"$tty" = X"1" ]; then echo "pause -1 \"Hit <return> to continue\""; fi
echo "quit"
} > $tmp2

$cmd $tmp2

exit 0
